pub struct ModelsResponse {
pub models: Vec<String>,
}Fields
models: Vec<String>Trait Implementations
Sourceimpl Clone for ModelsResponse
impl Clone for ModelsResponse
Sourcefn clone(&self) -> ModelsResponse
fn clone(&self) -> ModelsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModelsResponse
impl Debug for ModelsResponse
Sourceimpl<'de> Deserialize<'de> for ModelsResponse
impl<'de> Deserialize<'de> for ModelsResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ModelsResponse
impl JsonSchema for ModelsResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ModelsResponse
impl PartialEq for ModelsResponse
Sourceimpl Serialize for ModelsResponse
impl Serialize for ModelsResponse
impl StructuralPartialEq for ModelsResponse