pub struct NftInfoResponse<T> {
pub model_id: String,
pub token_uri: String,
pub size: String,
pub extension: T,
}Fields
model_id: Stringtoken_uri: Stringsize: Stringextension: TTrait Implementations
Sourceimpl<T: Clone> Clone for NftInfoResponse<T>
impl<T: Clone> Clone for NftInfoResponse<T>
Sourcefn clone(&self) -> NftInfoResponse<T>
fn clone(&self) -> NftInfoResponse<T>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<T: Debug> Debug for NftInfoResponse<T>
impl<T: Debug> Debug for NftInfoResponse<T>
Sourceimpl<'de, T> Deserialize<'de> for NftInfoResponse<T>where
T: Deserialize<'de>,
impl<'de, T> Deserialize<'de> for NftInfoResponse<T>where
T: Deserialize<'de>,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<T: JsonSchema> JsonSchema for NftInfoResponse<T>
impl<T: JsonSchema> JsonSchema for NftInfoResponse<T>
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl<T: PartialEq> PartialEq for NftInfoResponse<T>
impl<T: PartialEq> PartialEq for NftInfoResponse<T>
Sourceimpl<T> Serialize for NftInfoResponse<T>where
T: Serialize,
impl<T> Serialize for NftInfoResponse<T>where
T: Serialize,
impl<T: PartialEq> StructuralPartialEq for NftInfoResponse<T>