pub struct NumModelsResponse {
pub count: u64,
}Fields
count: u64Trait Implementations
Sourceimpl Clone for NumModelsResponse
impl Clone for NumModelsResponse
Sourcefn clone(&self) -> NumModelsResponse
fn clone(&self) -> NumModelsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NumModelsResponse
impl Debug for NumModelsResponse
Sourceimpl<'de> Deserialize<'de> for NumModelsResponse
impl<'de> Deserialize<'de> for NumModelsResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for NumModelsResponse
impl JsonSchema for NumModelsResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for NumModelsResponse
impl PartialEq for NumModelsResponse
Sourceimpl Serialize for NumModelsResponse
impl Serialize for NumModelsResponse
impl StructuralPartialEq for NumModelsResponse