pub struct ModelInfo<T> {
pub model_id: String,
pub owner: Addr,
pub model_uri: String,
pub extension: T,
}Fields
model_id: StringId of this model
owner: AddrThe owner of the newly shoe model
model_uri: Stringextension: TTrait Implementations
Sourceimpl<'de, T> Deserialize<'de> for ModelInfo<T>where
T: Deserialize<'de>,
impl<'de, T> Deserialize<'de> for ModelInfo<T>where
T: Deserialize<'de>,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<'a, T> IndexList<ModelInfo<T>> for ModelIndexes<'a, T>
impl<'a, T> IndexList<ModelInfo<T>> for ModelIndexes<'a, T>
Sourceimpl<T: JsonSchema> JsonSchema for ModelInfo<T>
impl<T: JsonSchema> JsonSchema for ModelInfo<T>
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreimpl<T: PartialEq> StructuralPartialEq for ModelInfo<T>